@@ -831,8 +831,8 @@ class account():
                     return self.avatars.get_value(item, 0)
             item = self.avatars.iter_next(item)
         #if we make it here we didn't have it loaded already
-        if (os.path.isfile("/home/user/.witterPics/" + filename)):
-            pixbuf = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + filename)
+        if (os.path.isfile("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)):
+            pixbuf = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
             pixbuf = pixbuf.scale_simple(self.avatar_size, self.avatar_size, gtk.gdk.INTERP_BILINEAR)
             self.avatars.append([pixbuf, filename, 1, name])
             print "loaded pixbuf from file"
@@ -860,6 +860,7 @@ class account():
                 os.mkdir("/home/user/.witterPics")
             if (os.path.isdir("/home/user/.witterPics/" + self.accountdata.servicename) != True):
                 os.mkdir("/home/user/.witterPics/" + self.accountdata.servicename)
+
             webFile = urllib.urlopen(url)
             print "fetched image"
             localFile = open("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename, 'w')
@@ -873,10 +874,15 @@ class account():
             print "failed to retreive picture for " + url + " : " + filename
             pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/tweet.png")
             return pixbuf, False
-
+        except UnicodeError, e2:
+            print e2
+            print "failed to retreive picture for " + url + " : " + filename
+            pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/tweet.png")
+            return pixbuf, False
         return pixbuf, True
 
     def format_tweet(self, user, tweet, time, source, reply_to):
+        tweet = tweet.replace("&amp;", "&")
         tweet = gobject.markup_escape_text(tweet)
         if (source != None):
             source = gobject.markup_escape_text(source)
