@@ -1310,7 +1310,7 @@ class Api(object):
     self._InitializeDefaultParameters()
     self._input_encoding = input_encoding
     self.SetCredentials(username, password)
-    self._base_url = "https://twitter.com/"
+    self._base_url = "https://api.twitter.com/1/"
     self._base_search_url = "https://search.twitter.com/"
 
   def GetPublicTimeline(self, since_id=None):
