@@ -812,7 +812,7 @@ class WitterUI():
                     label.set_use_markup(True)
                     label.set_line_wrap(True)
                     label.set_selectable(True)
-                    label.select_region(0, 1)
+
                     hboxTweet.pack_start(label, expand=True)
 
                     id = select1.get_value(select1.get_iter(item), 4)
@@ -842,11 +842,12 @@ class WitterUI():
                         for word in L :
                             if re.search("@", word):
                                 user = word
+                                if (re.search(self.controller.activeAccount.getUsername().lower(), user.lower())):
+                                    print "excluding self from reply all"
+                                else:
+                                    self.controller.reply_all = self.controller.reply_all + " " + user
                                 if (user != name):
-                                    if (re.search(self.controller.activeAccount.getUsername().lower(), user.lower())):
-                                        print "excluding self from reply all"
-                                    else:
-                                        self.controller.reply_all = self.controller.reply_all + " " + user
+
                                     b = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
                                     b.set_title('Follow')
@@ -856,7 +857,7 @@ class WitterUI():
                                     b2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
 
-                                    b2.set_value(user)
+                                    b2.set_title(user)
                                     b2.connect("clicked", self.controller.tweetAtUser, user)
                                     hbox1.pack_start(b2, expand=True)
                                     b3 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
