@@ -299,6 +299,13 @@ class Witter():
 
         print "We tried to open a browser"
 
+    def Translate(self, widget, text, *args):
+        #open a url in a browser
+
+        url = "http://translate.google.com/#auto|en|"
+        translateText = urllib.quote(text)
+        self.openBrowser(widget, url + translateText)
+
     def checkVersion(self):
         #we want to see if we're on fremantle or not as the default colour
         #scheme has changed
